brainpool

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package brainpool is a collection of named elliptic curves.

ECC Brainpool Standard Curves and Curve Generation v. 1.0 19.10.2005

https://neuromancer.sk/std/brainpool/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BrainpoolP160r1

func BrainpoolP160r1() elliptic.Curve

BrainpoolP160r1 returns a Curve which implements brainpool/brainpoolP160r1 https://neuromancer.sk/std/brainpool/brainpoolP160r1

OID: 1.3.36.3.3.2.8.1.1.1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP160t1

func BrainpoolP160t1() elliptic.Curve

BrainpoolP160t1 returns a Curve which implements brainpool/brainpoolP160t1 https://neuromancer.sk/std/brainpool/brainpoolP160t1

OID: 1.3.36.3.3.2.8.1.1.2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP192r1

func BrainpoolP192r1() elliptic.Curve

BrainpoolP192r1 returns a Curve which implements brainpool/brainpoolP192r1 https://neuromancer.sk/std/brainpool/brainpoolP192r1

OID: 1.3.36.3.3.2.8.1.1.3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP192t1

func BrainpoolP192t1() elliptic.Curve

BrainpoolP192t1 returns a Curve which implements brainpool/brainpoolP192t1 https://neuromancer.sk/std/brainpool/brainpoolP192t1

OID: 1.3.36.3.3.2.8.1.1.4

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP224r1

func BrainpoolP224r1() elliptic.Curve

BrainpoolP224r1 returns a Curve which implements brainpool/brainpoolP224r1 https://neuromancer.sk/std/brainpool/brainpoolP224r1

OID: 1.3.36.3.3.2.8.1.1.5

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP224t1

func BrainpoolP224t1() elliptic.Curve

BrainpoolP224t1 returns a Curve which implements brainpool/brainpoolP224t1 https://neuromancer.sk/std/brainpool/brainpoolP224t1

OID: 1.3.36.3.3.2.8.1.1.6

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP256r1

func BrainpoolP256r1() elliptic.Curve

BrainpoolP256r1 returns a Curve which implements brainpool/brainpoolP256r1 https://neuromancer.sk/std/brainpool/brainpoolP256r1

OID: 1.3.36.3.3.2.8.1.1.7

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP256t1

func BrainpoolP256t1() elliptic.Curve

BrainpoolP256t1 returns a Curve which implements brainpool/brainpoolP256t1 https://neuromancer.sk/std/brainpool/brainpoolP256t1

OID: 1.3.36.3.3.2.8.1.1.8

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP320r1

func BrainpoolP320r1() elliptic.Curve

BrainpoolP320r1 returns a Curve which implements brainpool/brainpoolP320r1 https://neuromancer.sk/std/brainpool/brainpoolP320r1

OID: 1.3.36.3.3.2.8.1.1.9

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP320t1

func BrainpoolP320t1() elliptic.Curve

BrainpoolP320t1 returns a Curve which implements brainpool/brainpoolP320t1 https://neuromancer.sk/std/brainpool/brainpoolP320t1

OID: 1.3.36.3.3.2.8.1.1.10

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP384r1

func BrainpoolP384r1() elliptic.Curve

BrainpoolP384r1 returns a Curve which implements brainpool/brainpoolP384r1 https://neuromancer.sk/std/brainpool/brainpoolP384r1

OID: 1.3.36.3.3.2.8.1.1.11

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP384t1

func BrainpoolP384t1() elliptic.Curve

BrainpoolP384t1 returns a Curve which implements brainpool/brainpoolP384t1 https://neuromancer.sk/std/brainpool/brainpoolP384t1

OID: 1.3.36.3.3.2.8.1.1.12

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP512r1

func BrainpoolP512r1() elliptic.Curve

BrainpoolP512r1 returns a Curve which implements brainpool/brainpoolP512r1 https://neuromancer.sk/std/brainpool/brainpoolP512r1

OID: 1.3.36.3.3.2.8.1.1.13

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BrainpoolP512t1

func BrainpoolP512t1() elliptic.Curve

BrainpoolP512t1 returns a Curve which implements brainpool/brainpoolP512t1 https://neuromancer.sk/std/brainpool/brainpoolP512t1

OID: 1.3.36.3.3.2.8.1.1.14

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to