mnt

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package mnt is a collection of named elliptic curves.

MNT (Miyaji, Nakabayashi, and Takano curves) example curves from: New explicit conditions of elliptic curve traces for FR-reduction - https://dspace.jaist.ac.jp/dspace/bitstream/10119/4432/1/73-48.pdf.

https://neuromancer.sk/std/mnt/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Mnt1

func Mnt1() elliptic.Curve

Mnt1 returns a Curve which implements mnt/mnt1 https://neuromancer.sk/std/mnt/mnt1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt2_1

func Mnt2_1() elliptic.Curve

Mnt2_1 returns a Curve which implements mnt/mnt2/1 https://neuromancer.sk/std/mnt/mnt2/1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt2_2

func Mnt2_2() elliptic.Curve

Mnt2_2 returns a Curve which implements mnt/mnt2/2 https://neuromancer.sk/std/mnt/mnt2/2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt3_1

func Mnt3_1() elliptic.Curve

Mnt3_1 returns a Curve which implements mnt/mnt3/1 https://neuromancer.sk/std/mnt/mnt3/1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt3_2

func Mnt3_2() elliptic.Curve

Mnt3_2 returns a Curve which implements mnt/mnt3/2 https://neuromancer.sk/std/mnt/mnt3/2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt3_3

func Mnt3_3() elliptic.Curve

Mnt3_3 returns a Curve which implements mnt/mnt3/3 https://neuromancer.sk/std/mnt/mnt3/3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt4

func Mnt4() elliptic.Curve

Mnt4 returns a Curve which implements mnt/mnt4 https://neuromancer.sk/std/mnt/mnt4

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt5_1

func Mnt5_1() elliptic.Curve

Mnt5_1 returns a Curve which implements mnt/mnt5/1 https://neuromancer.sk/std/mnt/mnt5/1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt5_2

func Mnt5_2() elliptic.Curve

Mnt5_2 returns a Curve which implements mnt/mnt5/2 https://neuromancer.sk/std/mnt/mnt5/2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Mnt5_3

func Mnt5_3() elliptic.Curve

Mnt5_3 returns a Curve which implements mnt/mnt5/3 https://neuromancer.sk/std/mnt/mnt5/3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to