nums

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package nums is a collection of named elliptic curves.

Microsoft Nothing Up My Sleeve (NUMS) curves from: <https://eprint.iacr.org/2014/130> and <https://tools.ietf.org/html/draft-black-numscurves-02>

https://neuromancer.sk/std/nums/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Ed254Mont

func Ed254Mont() elliptic.Curve

Ed254Mont returns a Curve which implements nums/ed-254-mont https://neuromancer.sk/std/nums/ed-254-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed255Mers

func Ed255Mers() elliptic.Curve

Ed255Mers returns a Curve which implements nums/ed-255-mers https://neuromancer.sk/std/nums/ed-255-mers

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed256Mont

func Ed256Mont() elliptic.Curve

Ed256Mont returns a Curve which implements nums/ed-256-mont https://neuromancer.sk/std/nums/ed-256-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed382Mont

func Ed382Mont() elliptic.Curve

Ed382Mont returns a Curve which implements nums/ed-382-mont https://neuromancer.sk/std/nums/ed-382-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed383Mers

func Ed383Mers() elliptic.Curve

Ed383Mers returns a Curve which implements nums/ed-383-mers https://neuromancer.sk/std/nums/ed-383-mers

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed384Mont

func Ed384Mont() elliptic.Curve

Ed384Mont returns a Curve which implements nums/ed-384-mont https://neuromancer.sk/std/nums/ed-384-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed510Mont

func Ed510Mont() elliptic.Curve

Ed510Mont returns a Curve which implements nums/ed-510-mont https://neuromancer.sk/std/nums/ed-510-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed511Mers

func Ed511Mers() elliptic.Curve

Ed511Mers returns a Curve which implements nums/ed-511-mers https://neuromancer.sk/std/nums/ed-511-mers

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed512Mont

func Ed512Mont() elliptic.Curve

Ed512Mont returns a Curve which implements nums/ed-512-mont https://neuromancer.sk/std/nums/ed-512-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Numsp256d1

func Numsp256d1() elliptic.Curve

Numsp256d1 returns a Curve which implements nums/numsp256d1 https://neuromancer.sk/std/nums/numsp256d1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Numsp256t1

func Numsp256t1() elliptic.Curve

Numsp256t1 returns a Curve which implements nums/numsp256t1 https://neuromancer.sk/std/nums/numsp256t1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Numsp384d1

func Numsp384d1() elliptic.Curve

Numsp384d1 returns a Curve which implements nums/numsp384d1 https://neuromancer.sk/std/nums/numsp384d1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Numsp384t1

func Numsp384t1() elliptic.Curve

Numsp384t1 returns a Curve which implements nums/numsp384t1 https://neuromancer.sk/std/nums/numsp384t1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Numsp512d1

func Numsp512d1() elliptic.Curve

Numsp512d1 returns a Curve which implements nums/numsp512d1 https://neuromancer.sk/std/nums/numsp512d1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Numsp512t1

func Numsp512t1() elliptic.Curve

Numsp512t1 returns a Curve which implements nums/numsp512t1 https://neuromancer.sk/std/nums/numsp512t1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W254Mont

func W254Mont() elliptic.Curve

W254Mont returns a Curve which implements nums/w-254-mont https://neuromancer.sk/std/nums/w-254-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W255Mers

func W255Mers() elliptic.Curve

W255Mers returns a Curve which implements nums/w-255-mers https://neuromancer.sk/std/nums/w-255-mers

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W256Mont

func W256Mont() elliptic.Curve

W256Mont returns a Curve which implements nums/w-256-mont https://neuromancer.sk/std/nums/w-256-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W382Mont

func W382Mont() elliptic.Curve

W382Mont returns a Curve which implements nums/w-382-mont https://neuromancer.sk/std/nums/w-382-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W383Mers

func W383Mers() elliptic.Curve

W383Mers returns a Curve which implements nums/w-383-mers https://neuromancer.sk/std/nums/w-383-mers

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W384Mont

func W384Mont() elliptic.Curve

W384Mont returns a Curve which implements nums/w-384-mont https://neuromancer.sk/std/nums/w-384-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W510Mont

func W510Mont() elliptic.Curve

W510Mont returns a Curve which implements nums/w-510-mont https://neuromancer.sk/std/nums/w-510-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W511Mers

func W511Mers() elliptic.Curve

W511Mers returns a Curve which implements nums/w-511-mers https://neuromancer.sk/std/nums/w-511-mers

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func W512Mont

func W512Mont() elliptic.Curve

W512Mont returns a Curve which implements nums/w-512-mont https://neuromancer.sk/std/nums/w-512-mont

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to