oakley

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package oakley is a collection of named elliptic curves.

Oakley groups from <https://tools.ietf.org/html/rfc2409> and <https://tools.ietf.org/html/rfc5114>

https://neuromancer.sk/std/oakley/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Oakley192BitRandomECPGroup

func Oakley192BitRandomECPGroup() elliptic.Curve

Oakley192BitRandomECPGroup returns a Curve which implements oakley/192-bit Random ECP Group https://neuromancer.sk/std/oakley/192-bit%20Random%20ECP%20Group

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Oakley224BitRandomECPGroup

func Oakley224BitRandomECPGroup() elliptic.Curve

Oakley224BitRandomECPGroup returns a Curve which implements oakley/224-bit Random ECP Group https://neuromancer.sk/std/oakley/224-bit%20Random%20ECP%20Group

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Oakley256BitRandomECPGroup

func Oakley256BitRandomECPGroup() elliptic.Curve

Oakley256BitRandomECPGroup returns a Curve which implements oakley/256-bit Random ECP Group https://neuromancer.sk/std/oakley/256-bit%20Random%20ECP%20Group

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Oakley384BitRandomECPGroup

func Oakley384BitRandomECPGroup() elliptic.Curve

Oakley384BitRandomECPGroup returns a Curve which implements oakley/384-bit Random ECP Group https://neuromancer.sk/std/oakley/384-bit%20Random%20ECP%20Group

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Oakley521BitRandomECPGroup

func Oakley521BitRandomECPGroup() elliptic.Curve

Oakley521BitRandomECPGroup returns a Curve which implements oakley/521-bit Random ECP Group https://neuromancer.sk/std/oakley/521-bit%20Random%20ECP%20Group

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func OakleyGroup3

func OakleyGroup3() elliptic.Curve

OakleyGroup3 returns a Curve which implements oakley/Oakley Group 3 https://neuromancer.sk/std/oakley/Oakley%20Group%203

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func OakleyGroup4

func OakleyGroup4() elliptic.Curve

OakleyGroup4 returns a Curve which implements oakley/Oakley Group 4 https://neuromancer.sk/std/oakley/Oakley%20Group%204

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to