oscaa

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package oscaa is a collection of named elliptic curves.

http://gmssl.org/english.html

https://neuromancer.sk/std/oscaa/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SM2

func SM2() elliptic.Curve

SM2 returns a Curve which implements oscaa/SM2 https://neuromancer.sk/std/oscaa/SM2

OID: 1.2.156.10197.1.301

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to