other

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package other is a collection of named elliptic curves.

An assortment of some other curves.

https://neuromancer.sk/std/other/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BADA55R256

func BADA55R256() elliptic.Curve

BADA55R256 returns a Curve which implements other/BADA55-R-256 https://neuromancer.sk/std/other/BADA55-R-256

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BADA55VPR2_224

func BADA55VPR2_224() elliptic.Curve

BADA55VPR2_224 returns a Curve which implements other/BADA55-VPR2-224 https://neuromancer.sk/std/other/BADA55-VPR2-224

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BADA55VPR224

func BADA55VPR224() elliptic.Curve

BADA55VPR224 returns a Curve which implements other/BADA55-VPR-224 https://neuromancer.sk/std/other/BADA55-VPR-224

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BADA55VR224

func BADA55VR224() elliptic.Curve

BADA55VR224 returns a Curve which implements other/BADA55-VR-224 https://neuromancer.sk/std/other/BADA55-VR-224

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BADA55VR256

func BADA55VR256() elliptic.Curve

BADA55VR256 returns a Curve which implements other/BADA55-VR-256 https://neuromancer.sk/std/other/BADA55-VR-256

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func BADA55VR384

func BADA55VR384() elliptic.Curve

BADA55VR384 returns a Curve which implements other/BADA55-VR-384 https://neuromancer.sk/std/other/BADA55-VR-384

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve448

func Curve448() elliptic.Curve

Curve448 returns a Curve which implements other/Curve448 https://neuromancer.sk/std/other/Curve448

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve1174

func Curve1174() elliptic.Curve

Curve1174 returns a Curve which implements other/Curve1174 https://neuromancer.sk/std/other/Curve1174

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve4417

func Curve4417() elliptic.Curve

Curve4417 returns a Curve which implements other/Curve4417 https://neuromancer.sk/std/other/Curve4417

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve22103

func Curve22103() elliptic.Curve

Curve22103 returns a Curve which implements other/Curve22103 https://neuromancer.sk/std/other/Curve22103

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve25519

func Curve25519() elliptic.Curve

Curve25519 returns a Curve which implements other/Curve25519 https://neuromancer.sk/std/other/Curve25519

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve41417

func Curve41417() elliptic.Curve

Curve41417 returns a Curve which implements other/Curve41417 https://neuromancer.sk/std/other/Curve41417

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve67254

func Curve67254() elliptic.Curve

Curve67254 returns a Curve which implements other/Curve67254 https://neuromancer.sk/std/other/Curve67254

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Curve383187

func Curve383187() elliptic.Curve

Curve383187 returns a Curve which implements other/Curve383187 https://neuromancer.sk/std/other/Curve383187

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func E222

func E222() elliptic.Curve

E222 returns a Curve which implements other/E-222 https://neuromancer.sk/std/other/E-222

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func E382

func E382() elliptic.Curve

E382 returns a Curve which implements other/E-382 https://neuromancer.sk/std/other/E-382

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func E521

func E521() elliptic.Curve

E521 returns a Curve which implements other/E-521 https://neuromancer.sk/std/other/E-521

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed448

func Ed448() elliptic.Curve

Ed448 returns a Curve which implements other/Ed448 https://neuromancer.sk/std/other/Ed448

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed448Goldilocks

func Ed448Goldilocks() elliptic.Curve

Ed448Goldilocks returns a Curve which implements other/Ed448-Goldilocks https://neuromancer.sk/std/other/Ed448-Goldilocks

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ed25519

func Ed25519() elliptic.Curve

Ed25519 returns a Curve which implements other/Ed25519 https://neuromancer.sk/std/other/Ed25519

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Fp224BN

func Fp224BN() elliptic.Curve

Fp224BN returns a Curve which implements other/Fp224BN https://neuromancer.sk/std/other/Fp224BN

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Fp254BNa

func Fp254BNa() elliptic.Curve

Fp254BNa returns a Curve which implements other/Fp254BNa https://neuromancer.sk/std/other/Fp254BNa

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Fp254BNb

func Fp254BNb() elliptic.Curve

Fp254BNb returns a Curve which implements other/Fp254BNb https://neuromancer.sk/std/other/Fp254BNb Aliases:

  • bn/bn254

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Fp256BN

func Fp256BN() elliptic.Curve

Fp256BN returns a Curve which implements other/Fp256BN https://neuromancer.sk/std/other/Fp256BN

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Fp384BN

func Fp384BN() elliptic.Curve

Fp384BN returns a Curve which implements other/Fp384BN https://neuromancer.sk/std/other/Fp384BN

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Fp512BN

func Fp512BN() elliptic.Curve

Fp512BN returns a Curve which implements other/Fp512BN https://neuromancer.sk/std/other/Fp512BN

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func JubJub

func JubJub() elliptic.Curve

JubJub returns a Curve which implements other/JubJub https://neuromancer.sk/std/other/JubJub

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func M221

func M221() elliptic.Curve

M221 returns a Curve which implements other/M-221 https://neuromancer.sk/std/other/M-221

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func M383

func M383() elliptic.Curve

M383 returns a Curve which implements other/M-383 https://neuromancer.sk/std/other/M-383

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func M511

func M511() elliptic.Curve

M511 returns a Curve which implements other/M-511 https://neuromancer.sk/std/other/M-511

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func MDC201601

func MDC201601() elliptic.Curve

MDC201601 returns a Curve which implements other/MDC201601 https://neuromancer.sk/std/other/MDC201601

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Pallas

func Pallas() elliptic.Curve

Pallas returns a Curve which implements other/Pallas https://neuromancer.sk/std/other/Pallas

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc160

func Ssc160() elliptic.Curve

Ssc160 returns a Curve which implements other/ssc-160 https://neuromancer.sk/std/other/ssc-160

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc192

func Ssc192() elliptic.Curve

Ssc192 returns a Curve which implements other/ssc-192 https://neuromancer.sk/std/other/ssc-192

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc224

func Ssc224() elliptic.Curve

Ssc224 returns a Curve which implements other/ssc-224 https://neuromancer.sk/std/other/ssc-224

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc256

func Ssc256() elliptic.Curve

Ssc256 returns a Curve which implements other/ssc-256 https://neuromancer.sk/std/other/ssc-256

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc288

func Ssc288() elliptic.Curve

Ssc288 returns a Curve which implements other/ssc-288 https://neuromancer.sk/std/other/ssc-288

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc320

func Ssc320() elliptic.Curve

Ssc320 returns a Curve which implements other/ssc-320 https://neuromancer.sk/std/other/ssc-320

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc384

func Ssc384() elliptic.Curve

Ssc384 returns a Curve which implements other/ssc-384 https://neuromancer.sk/std/other/ssc-384

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ssc512

func Ssc512() elliptic.Curve

Ssc512 returns a Curve which implements other/ssc-512 https://neuromancer.sk/std/other/ssc-512

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Tom256

func Tom256() elliptic.Curve

Tom256 returns a Curve which implements other/Tom-256 https://neuromancer.sk/std/other/Tom-256

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Tom384

func Tom384() elliptic.Curve

Tom384 returns a Curve which implements other/Tom-384 https://neuromancer.sk/std/other/Tom-384

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Tom521

func Tom521() elliptic.Curve

Tom521 returns a Curve which implements other/Tom-521 https://neuromancer.sk/std/other/Tom-521

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Tweedledee

func Tweedledee() elliptic.Curve

Tweedledee returns a Curve which implements other/Tweedledee https://neuromancer.sk/std/other/Tweedledee

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Tweedledum

func Tweedledum() elliptic.Curve

Tweedledum returns a Curve which implements other/Tweedledum https://neuromancer.sk/std/other/Tweedledum

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Vesta

func Vesta() elliptic.Curve

Vesta returns a Curve which implements other/Vesta https://neuromancer.sk/std/other/Vesta

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to