secg

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package secg is a collection of named elliptic curves.

SEC 2: Recommended Elliptic Curve Domain Parameters version 2.0 January 27, 2010

https://neuromancer.sk/std/secg/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Secp112r1 added in v1.1.0

func Secp112r1() elliptic.Curve

Secp112r1 returns a Curve which implements secg/secp112r1 https://neuromancer.sk/std/secg/secp112r1

OID: 1.3.132.0.6 Aliases:

  • wtls/wap-wsg-idm-ecid-wtls6

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp112r2 added in v1.1.0

func Secp112r2() elliptic.Curve

Secp112r2 returns a Curve which implements secg/secp112r2 https://neuromancer.sk/std/secg/secp112r2

OID: 1.3.132.0.7

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp128r1 added in v1.1.0

func Secp128r1() elliptic.Curve

Secp128r1 returns a Curve which implements secg/secp128r1 https://neuromancer.sk/std/secg/secp128r1

OID: 1.3.132.0.28

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp128r2 added in v1.1.0

func Secp128r2() elliptic.Curve

Secp128r2 returns a Curve which implements secg/secp128r2 https://neuromancer.sk/std/secg/secp128r2

OID: 1.3.132.0.29

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp160k1 added in v1.1.0

func Secp160k1() elliptic.Curve

Secp160k1 returns a Curve which implements secg/secp160k1 https://neuromancer.sk/std/secg/secp160k1

OID: 1.3.132.0.9 Aliases:

  • x963/ansip160k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp160r1 added in v1.1.0

func Secp160r1() elliptic.Curve

Secp160r1 returns a Curve which implements secg/secp160r1 https://neuromancer.sk/std/secg/secp160r1

OID: 1.3.132.0.8 Aliases:

  • wtls/wap-wsg-idm-ecid-wtls7
  • x963/ansip160r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp160r2 added in v1.1.0

func Secp160r2() elliptic.Curve

Secp160r2 returns a Curve which implements secg/secp160r2 https://neuromancer.sk/std/secg/secp160r2

OID: 1.3.132.0.30 Aliases:

  • x963/ansip160r2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp192k1 added in v1.1.0

func Secp192k1() elliptic.Curve

Secp192k1 returns a Curve which implements secg/secp192k1 https://neuromancer.sk/std/secg/secp192k1

OID: 1.3.132.0.31 Aliases:

  • x963/ansip192k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp192r1 added in v1.1.0

func Secp192r1() elliptic.Curve

Secp192r1 returns a Curve which implements secg/secp192r1 https://neuromancer.sk/std/secg/secp192r1

OID: 1.2.840.10045.3.1.1 Aliases:

  • nist/P-192
  • x962/prime192v1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp224k1 added in v1.1.0

func Secp224k1() elliptic.Curve

Secp224k1 returns a Curve which implements secg/secp224k1 https://neuromancer.sk/std/secg/secp224k1

OID: 1.3.132.0.32 Aliases:

  • x963/ansip224k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp224r1 added in v1.1.0

func Secp224r1() elliptic.Curve

Secp224r1 returns a Curve which implements secg/secp224r1 https://neuromancer.sk/std/secg/secp224r1

OID: 1.3.132.0.33 Aliases:

  • nist/P-224
  • wtls/wap-wsg-idm-ecid-wtls12
  • x963/ansip224r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp256k1 added in v1.1.0

func Secp256k1() elliptic.Curve

Secp256k1 returns a Curve which implements secg/secp256k1 https://neuromancer.sk/std/secg/secp256k1

OID: 1.3.132.0.10 Aliases:

  • x963/ansip256k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp256r1 added in v1.1.0

func Secp256r1() elliptic.Curve

Secp256r1 returns a Curve which implements secg/secp256r1 https://neuromancer.sk/std/secg/secp256r1

OID: 1.2.840.10045.3.1.7 Aliases:

  • nist/P-256
  • x962/prime256v1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp384r1 added in v1.1.0

func Secp384r1() elliptic.Curve

Secp384r1 returns a Curve which implements secg/secp384r1 https://neuromancer.sk/std/secg/secp384r1

OID: 1.3.132.0.34 Aliases:

  • nist/P-384
  • x963/ansip384r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Secp521r1 added in v1.1.0

func Secp521r1() elliptic.Curve

Secp521r1 returns a Curve which implements secg/secp521r1 https://neuromancer.sk/std/secg/secp521r1

OID: 1.3.132.0.35 Aliases:

  • nist/P-521
  • x963/ansip521r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect113r1

func Sect113r1() elliptic.Curve

Sect113r1 returns a Curve which implements secg/sect113r1 https://neuromancer.sk/std/secg/sect113r1

OID: 1.3.132.0.4 Aliases:

  • wtls/wap-wsg-idm-ecid-wtls4

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect113r2

func Sect113r2() elliptic.Curve

Sect113r2 returns a Curve which implements secg/sect113r2 https://neuromancer.sk/std/secg/sect113r2

OID: 1.3.132.0.5

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect131r1

func Sect131r1() elliptic.Curve

Sect131r1 returns a Curve which implements secg/sect131r1 https://neuromancer.sk/std/secg/sect131r1

OID: 1.3.132.0.22

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect131r2

func Sect131r2() elliptic.Curve

Sect131r2 returns a Curve which implements secg/sect131r2 https://neuromancer.sk/std/secg/sect131r2

OID: 1.3.132.0.23

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect163k1

func Sect163k1() elliptic.Curve

Sect163k1 returns a Curve which implements secg/sect163k1 https://neuromancer.sk/std/secg/sect163k1

OID: 1.3.132.0.1 Aliases:

  • nist/K-163
  • x963/ansit163k1
  • wtls/wap-wsg-idm-ecid-wtls3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect163r1

func Sect163r1() elliptic.Curve

Sect163r1 returns a Curve which implements secg/sect163r1 https://neuromancer.sk/std/secg/sect163r1

OID: 1.3.132.0.2 Aliases:

  • x963/ansit163r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect163r2

func Sect163r2() elliptic.Curve

Sect163r2 returns a Curve which implements secg/sect163r2 https://neuromancer.sk/std/secg/sect163r2

OID: 1.3.132.0.15 Aliases:

  • nist/B-163
  • x963/ansit163r2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect193r1

func Sect193r1() elliptic.Curve

Sect193r1 returns a Curve which implements secg/sect193r1 https://neuromancer.sk/std/secg/sect193r1

OID: 1.3.132.0.24 Aliases:

  • x963/ansit193r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect193r2

func Sect193r2() elliptic.Curve

Sect193r2 returns a Curve which implements secg/sect193r2 https://neuromancer.sk/std/secg/sect193r2

OID: 1.3.132.0.25 Aliases:

  • x963/ansit193r2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect233k1

func Sect233k1() elliptic.Curve

Sect233k1 returns a Curve which implements secg/sect233k1 https://neuromancer.sk/std/secg/sect233k1

OID: 1.3.132.0.26 Aliases:

  • nist/K-233
  • wtls/wap-wsg-idm-ecid-wtls10
  • x963/ansit233k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect233r1

func Sect233r1() elliptic.Curve

Sect233r1 returns a Curve which implements secg/sect233r1 https://neuromancer.sk/std/secg/sect233r1

OID: 1.3.132.0.27 Aliases:

  • nist/B-233
  • wtls/wap-wsg-idm-ecid-wtls11
  • x963/ansit233r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect239k1

func Sect239k1() elliptic.Curve

Sect239k1 returns a Curve which implements secg/sect239k1 https://neuromancer.sk/std/secg/sect239k1

OID: 1.3.132.0.3 Aliases:

  • x963/ansit239k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect283k1

func Sect283k1() elliptic.Curve

Sect283k1 returns a Curve which implements secg/sect283k1 https://neuromancer.sk/std/secg/sect283k1

OID: 1.3.132.0.16 Aliases:

  • nist/K-283
  • x963/ansit283k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect283r1

func Sect283r1() elliptic.Curve

Sect283r1 returns a Curve which implements secg/sect283r1 https://neuromancer.sk/std/secg/sect283r1

OID: 1.3.132.0.17 Aliases:

  • nist/B-283
  • x963/ansit283r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect409k1

func Sect409k1() elliptic.Curve

Sect409k1 returns a Curve which implements secg/sect409k1 https://neuromancer.sk/std/secg/sect409k1

OID: 1.3.132.0.36 Aliases:

  • nist/K-409
  • x963/ansit409k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect409r1

func Sect409r1() elliptic.Curve

Sect409r1 returns a Curve which implements secg/sect409r1 https://neuromancer.sk/std/secg/sect409r1

OID: 1.3.132.0.37 Aliases:

  • nist/B-409
  • x963/ansit409r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect571k1

func Sect571k1() elliptic.Curve

Sect571k1 returns a Curve which implements secg/sect571k1 https://neuromancer.sk/std/secg/sect571k1

OID: 1.3.132.0.38 Aliases:

  • nist/K-571
  • x963/ansit571k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Sect571r1

func Sect571r1() elliptic.Curve

Sect571r1 returns a Curve which implements secg/sect571r1 https://neuromancer.sk/std/secg/sect571r1

OID: 1.3.132.0.39 Aliases:

  • nist/B-571
  • x963/ansit571r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to