x962

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package x962 is a collection of named elliptic curves.

ANSI x9.62 example curves.

https://neuromancer.sk/std/x962/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func C2pnb163v1

func C2pnb163v1() elliptic.Curve

C2pnb163v1 returns a Curve which implements x962/c2pnb163v1 https://neuromancer.sk/std/x962/c2pnb163v1

OID: 1.2.840.10045.3.0.1 Aliases:

  • wtls/wap-wsg-idm-ecid-wtls5

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb163v2

func C2pnb163v2() elliptic.Curve

C2pnb163v2 returns a Curve which implements x962/c2pnb163v2 https://neuromancer.sk/std/x962/c2pnb163v2

OID: 1.2.840.10045.3.0.2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb163v3

func C2pnb163v3() elliptic.Curve

C2pnb163v3 returns a Curve which implements x962/c2pnb163v3 https://neuromancer.sk/std/x962/c2pnb163v3

OID: 1.2.840.10045.3.0.3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb176w1

func C2pnb176w1() elliptic.Curve

C2pnb176w1 returns a Curve which implements x962/c2pnb176w1 https://neuromancer.sk/std/x962/c2pnb176w1

OID: 1.2.840.10045.3.0.4

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb208w1

func C2pnb208w1() elliptic.Curve

C2pnb208w1 returns a Curve which implements x962/c2pnb208w1 https://neuromancer.sk/std/x962/c2pnb208w1

OID: 1.2.840.10045.3.0.10

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb272w1

func C2pnb272w1() elliptic.Curve

C2pnb272w1 returns a Curve which implements x962/c2pnb272w1 https://neuromancer.sk/std/x962/c2pnb272w1

OID: 1.2.840.10045.3.0.16

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb304w1

func C2pnb304w1() elliptic.Curve

C2pnb304w1 returns a Curve which implements x962/c2pnb304w1 https://neuromancer.sk/std/x962/c2pnb304w1

OID: 1.2.840.10045.3.0.17

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2pnb368w1

func C2pnb368w1() elliptic.Curve

C2pnb368w1 returns a Curve which implements x962/c2pnb368w1 https://neuromancer.sk/std/x962/c2pnb368w1

OID: 1.2.840.10045.3.0.19

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb191v1

func C2tnb191v1() elliptic.Curve

C2tnb191v1 returns a Curve which implements x962/c2tnb191v1 https://neuromancer.sk/std/x962/c2tnb191v1

OID: 1.2.840.10045.3.0.5

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb191v2

func C2tnb191v2() elliptic.Curve

C2tnb191v2 returns a Curve which implements x962/c2tnb191v2 https://neuromancer.sk/std/x962/c2tnb191v2

OID: 1.2.840.10045.3.0.6

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb191v3

func C2tnb191v3() elliptic.Curve

C2tnb191v3 returns a Curve which implements x962/c2tnb191v3 https://neuromancer.sk/std/x962/c2tnb191v3

OID: 1.2.840.10045.3.0.7

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb239v1

func C2tnb239v1() elliptic.Curve

C2tnb239v1 returns a Curve which implements x962/c2tnb239v1 https://neuromancer.sk/std/x962/c2tnb239v1

OID: 1.2.840.10045.3.0.11

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb239v2

func C2tnb239v2() elliptic.Curve

C2tnb239v2 returns a Curve which implements x962/c2tnb239v2 https://neuromancer.sk/std/x962/c2tnb239v2

OID: 1.2.840.10045.3.0.12

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb239v3

func C2tnb239v3() elliptic.Curve

C2tnb239v3 returns a Curve which implements x962/c2tnb239v3 https://neuromancer.sk/std/x962/c2tnb239v3

OID: 1.2.840.10045.3.0.13

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb359v1

func C2tnb359v1() elliptic.Curve

C2tnb359v1 returns a Curve which implements x962/c2tnb359v1 https://neuromancer.sk/std/x962/c2tnb359v1

OID: 1.2.840.10045.3.0.18

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func C2tnb431r1

func C2tnb431r1() elliptic.Curve

C2tnb431r1 returns a Curve which implements x962/c2tnb431r1 https://neuromancer.sk/std/x962/c2tnb431r1

OID: 1.2.840.10045.3.0.20

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime192v1 added in v1.1.0

func Prime192v1() elliptic.Curve

Prime192v1 returns a Curve which implements x962/prime192v1 https://neuromancer.sk/std/x962/prime192v1

OID: 1.2.840.10045.3.1.1 Aliases:

  • secg/secp192r1
  • nist/P-192

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime192v2 added in v1.1.0

func Prime192v2() elliptic.Curve

Prime192v2 returns a Curve which implements x962/prime192v2 https://neuromancer.sk/std/x962/prime192v2

OID: 1.2.840.10045.3.1.2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime192v3 added in v1.1.0

func Prime192v3() elliptic.Curve

Prime192v3 returns a Curve which implements x962/prime192v3 https://neuromancer.sk/std/x962/prime192v3

OID: 1.2.840.10045.3.1.3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime239v1 added in v1.1.0

func Prime239v1() elliptic.Curve

Prime239v1 returns a Curve which implements x962/prime239v1 https://neuromancer.sk/std/x962/prime239v1

OID: 1.2.840.10045.3.1.4

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime239v2 added in v1.1.0

func Prime239v2() elliptic.Curve

Prime239v2 returns a Curve which implements x962/prime239v2 https://neuromancer.sk/std/x962/prime239v2

OID: 1.2.840.10045.3.1.5

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime239v3 added in v1.1.0

func Prime239v3() elliptic.Curve

Prime239v3 returns a Curve which implements x962/prime239v3 https://neuromancer.sk/std/x962/prime239v3

OID: 1.2.840.10045.3.1.6

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Prime256v1 added in v1.1.0

func Prime256v1() elliptic.Curve

Prime256v1 returns a Curve which implements x962/prime256v1 https://neuromancer.sk/std/x962/prime256v1

OID: 1.2.840.10045.3.1.7 Aliases:

  • secg/secp256r1
  • nist/P-256

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to