x963

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

package x963 is a collection of named elliptic curves.

ANSI x9.63 example curves.

https://neuromancer.sk/std/x963/

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Ansip160k1 added in v1.1.0

func Ansip160k1() elliptic.Curve

Ansip160k1 returns a Curve which implements x963/ansip160k1 https://neuromancer.sk/std/x963/ansip160k1

OID: 1.3.132.0.9 Aliases:

  • secg/secp160k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip160r1 added in v1.1.0

func Ansip160r1() elliptic.Curve

Ansip160r1 returns a Curve which implements x963/ansip160r1 https://neuromancer.sk/std/x963/ansip160r1

OID: 1.3.132.0.8 Aliases:

  • secg/secp160r1
  • wtls/wap-wsg-idm-ecid-wtls7

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip160r2 added in v1.1.0

func Ansip160r2() elliptic.Curve

Ansip160r2 returns a Curve which implements x963/ansip160r2 https://neuromancer.sk/std/x963/ansip160r2

OID: 1.3.132.0.30 Aliases:

  • secg/secp160r2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip192k1 added in v1.1.0

func Ansip192k1() elliptic.Curve

Ansip192k1 returns a Curve which implements x963/ansip192k1 https://neuromancer.sk/std/x963/ansip192k1

OID: 1.3.132.0.31 Aliases:

  • secg/secp192k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip224k1 added in v1.1.0

func Ansip224k1() elliptic.Curve

Ansip224k1 returns a Curve which implements x963/ansip224k1 https://neuromancer.sk/std/x963/ansip224k1

OID: 1.3.132.0.32 Aliases:

  • secg/secp224k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip224r1 added in v1.1.0

func Ansip224r1() elliptic.Curve

Ansip224r1 returns a Curve which implements x963/ansip224r1 https://neuromancer.sk/std/x963/ansip224r1

OID: 1.3.132.0.33 Aliases:

  • wtls/wap-wsg-idm-ecid-wtls12
  • nist/P-224
  • secg/secp224r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip256k1 added in v1.1.0

func Ansip256k1() elliptic.Curve

Ansip256k1 returns a Curve which implements x963/ansip256k1 https://neuromancer.sk/std/x963/ansip256k1

OID: 1.3.132.0.10 Aliases:

  • secg/secp256k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip384r1 added in v1.1.0

func Ansip384r1() elliptic.Curve

Ansip384r1 returns a Curve which implements x963/ansip384r1 https://neuromancer.sk/std/x963/ansip384r1

OID: 1.3.132.0.34 Aliases:

  • secg/secp384r1
  • nist/P-384

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansip521r1 added in v1.1.0

func Ansip521r1() elliptic.Curve

Ansip521r1 returns a Curve which implements x963/ansip521r1 https://neuromancer.sk/std/x963/ansip521r1

OID: 1.3.132.0.35 Aliases:

  • secg/secp521r1
  • nist/P-521

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit163k1

func Ansit163k1() elliptic.Curve

Ansit163k1 returns a Curve which implements x963/ansit163k1 https://neuromancer.sk/std/x963/ansit163k1

OID: 1.3.132.0.1 Aliases:

  • secg/sect163k1
  • nist/k-163
  • wtls/wap-wsg-idm-ecid-wtls3

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit163r1

func Ansit163r1() elliptic.Curve

Ansit163r1 returns a Curve which implements x963/ansit163r1 https://neuromancer.sk/std/x963/ansit163r1

OID: 1.3.132.0.2 Aliases:

  • secg/sect163r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit163r2

func Ansit163r2() elliptic.Curve

Ansit163r2 returns a Curve which implements x963/ansit163r2 https://neuromancer.sk/std/x963/ansit163r2

OID: 1.3.132.0.15 Aliases:

  • secg/sect163r2
  • nist/B-163

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit193r1

func Ansit193r1() elliptic.Curve

Ansit193r1 returns a Curve which implements x963/ansit193r1 https://neuromancer.sk/std/x963/ansit193r1

OID: 1.3.132.0.24 Aliases:

  • secg/sect193r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit193r2

func Ansit193r2() elliptic.Curve

Ansit193r2 returns a Curve which implements x963/ansit193r2 https://neuromancer.sk/std/x963/ansit193r2

OID: 1.3.132.0.25 Aliases:

  • secg/sect193r2

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit233k1

func Ansit233k1() elliptic.Curve

Ansit233k1 returns a Curve which implements x963/ansit233k1 https://neuromancer.sk/std/x963/ansit233k1

OID: 1.3.132.0.26 Aliases:

  • secg/sect233k1
  • nist/K-233
  • wtls/wap-wsg-idm-ecid-wtls10

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit233r1

func Ansit233r1() elliptic.Curve

Ansit233r1 returns a Curve which implements x963/ansit233r1 https://neuromancer.sk/std/x963/ansit233r1

OID: 1.3.132.0.27 Aliases:

  • wtls/wap-wsg-idm-ecid-wtls11
  • nist/B-233
  • secg/sect233r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit239k1

func Ansit239k1() elliptic.Curve

Ansit239k1 returns a Curve which implements x963/ansit239k1 https://neuromancer.sk/std/x963/ansit239k1

OID: 1.3.132.0.3 Aliases:

  • secg/sect239k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit283k1

func Ansit283k1() elliptic.Curve

Ansit283k1 returns a Curve which implements x963/ansit283k1 https://neuromancer.sk/std/x963/ansit283k1

OID: 1.3.132.0.16 Aliases:

  • nist/K-283
  • secg/sect283k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit283r1

func Ansit283r1() elliptic.Curve

Ansit283r1 returns a Curve which implements x963/ansit283r1 https://neuromancer.sk/std/x963/ansit283r1

OID: 1.3.132.0.17 Aliases:

  • nist/B-283
  • secg/sect283r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit409k1

func Ansit409k1() elliptic.Curve

Ansit409k1 returns a Curve which implements x963/ansit409k1 https://neuromancer.sk/std/x963/ansit409k1

OID: 1.3.132.0.36 Aliases:

  • nist/K-409
  • secg/sect409k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit409r1

func Ansit409r1() elliptic.Curve

Ansit409r1 returns a Curve which implements x963/ansit409r1 https://neuromancer.sk/std/x963/ansit409r1

OID: 1.3.132.0.37 Aliases:

  • nist/B-409
  • secg/sect409r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit571k1

func Ansit571k1() elliptic.Curve

Ansit571k1 returns a Curve which implements x963/ansit571k1 https://neuromancer.sk/std/x963/ansit571k1

OID: 1.3.132.0.38 Aliases:

  • nist/K-571
  • secg/sect571k1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

func Ansit571r1

func Ansit571r1() elliptic.Curve

Ansit571r1 returns a Curve which implements x963/ansit571r1 https://neuromancer.sk/std/x963/ansit571r1

OID: 1.3.132.0.39 Aliases:

  • nist/B-571
  • secg/sect571r1

Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.

Types

This section is empty.

Jump to