Documentation
¶
Overview ¶
package bls is a collection of named elliptic curves.
BLS curves. A family of pairing friendly curves, with embedding degree = 12 or 24.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BLS12_377 ¶
BLS12_377 returns a Curve which implements bls/BLS12-377 https://neuromancer.sk/std/bls/BLS12-377
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BLS12_381 ¶
BLS12_381 returns a Curve which implements bls/BLS12-381 https://neuromancer.sk/std/bls/BLS12-381
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BLS12_446 ¶
BLS12_446 returns a Curve which implements bls/BLS12-446 https://neuromancer.sk/std/bls/BLS12-446
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BLS12_455 ¶
BLS12_455 returns a Curve which implements bls/BLS12-455 https://neuromancer.sk/std/bls/BLS12-455
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BLS12_638 ¶
BLS12_638 returns a Curve which implements bls/BLS12-638 https://neuromancer.sk/std/bls/BLS12-638
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BLS24_477 ¶
BLS24_477 returns a Curve which implements bls/BLS24-477 https://neuromancer.sk/std/bls/BLS24-477
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BLS48_581G1 ¶ added in v1.2.0
BLS48_581G1 returns a Curve which implements bls/BLS48-581-G1 https://neuromancer.sk/std/bls/BLS48-581-G1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Bandersnatch ¶
Bandersnatch returns a Curve which implements bls/Bandersnatch https://neuromancer.sk/std/bls/Bandersnatch
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.