Documentation
¶
Overview ¶
package gost is a collection of named elliptic curves.
GOST curves from: [RFC5832](https://datatracker.ietf.org/doc/html/rfc5832), [RFC7836](https://datatracker.ietf.org/doc/html/rfc7836), and [RFC4357](https://datatracker.ietf.org/doc/html/rfc4357).
Index ¶
- func Gost256() elliptic.Curve
- func Gost512() elliptic.Curve
- func IdGostR3410_2001CryptoProAParamSet() elliptic.Curve
- func IdGostR3410_2001CryptoProBParamSet() elliptic.Curve
- func IdGostR3410_2001CryptoProCParamSet() elliptic.Curve
- func IdTc26Gost3410_12_512ParamSetA() elliptic.Curve
- func IdTc26Gost3410_12_512ParamSetB() elliptic.Curve
- func IdTc26Gost3410_2012_256ParamSetA() elliptic.Curve
- func IdTc26Gost3410_2012_512ParamSetC() elliptic.Curve
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Gost256 ¶
Gost256 returns a Curve which implements gost/gost256 https://neuromancer.sk/std/gost/gost256
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Gost512 ¶
Gost512 returns a Curve which implements gost/gost512 https://neuromancer.sk/std/gost/gost512
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdGostR3410_2001CryptoProAParamSet ¶
IdGostR3410_2001CryptoProAParamSet returns a Curve which implements gost/id-GostR3410-2001-CryptoPro-A-ParamSet https://neuromancer.sk/std/gost/id-GostR3410-2001-CryptoPro-A-ParamSet
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdGostR3410_2001CryptoProBParamSet ¶
IdGostR3410_2001CryptoProBParamSet returns a Curve which implements gost/id-GostR3410-2001-CryptoPro-B-ParamSet https://neuromancer.sk/std/gost/id-GostR3410-2001-CryptoPro-B-ParamSet
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdGostR3410_2001CryptoProCParamSet ¶
IdGostR3410_2001CryptoProCParamSet returns a Curve which implements gost/id-GostR3410-2001-CryptoPro-C-ParamSet https://neuromancer.sk/std/gost/id-GostR3410-2001-CryptoPro-C-ParamSet
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdTc26Gost3410_12_512ParamSetA ¶
IdTc26Gost3410_12_512ParamSetA returns a Curve which implements gost/id-tc26-gost-3410-12-512-paramSetA https://neuromancer.sk/std/gost/id-tc26-gost-3410-12-512-paramSetA
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdTc26Gost3410_12_512ParamSetB ¶
IdTc26Gost3410_12_512ParamSetB returns a Curve which implements gost/id-tc26-gost-3410-12-512-paramSetB https://neuromancer.sk/std/gost/id-tc26-gost-3410-12-512-paramSetB
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdTc26Gost3410_2012_256ParamSetA ¶
IdTc26Gost3410_2012_256ParamSetA returns a Curve which implements gost/id-tc26-gost-3410-2012-256-paramSetA https://neuromancer.sk/std/gost/id-tc26-gost-3410-2012-256-paramSetA
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func IdTc26Gost3410_2012_512ParamSetC ¶
IdTc26Gost3410_2012_512ParamSetC returns a Curve which implements gost/id-tc26-gost-3410-2012-512-paramSetC https://neuromancer.sk/std/gost/id-tc26-gost-3410-2012-512-paramSetC
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.