Documentation
¶
Overview ¶
package mnt is a collection of named elliptic curves.
MNT (Miyaji, Nakabayashi, and Takano curves) example curves from: New explicit conditions of elliptic curve traces for FR-reduction - https://dspace.jaist.ac.jp/dspace/bitstream/10119/4432/1/73-48.pdf.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Mnt1 ¶
Mnt1 returns a Curve which implements mnt/mnt1 https://neuromancer.sk/std/mnt/mnt1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt2_1 ¶
Mnt2_1 returns a Curve which implements mnt/mnt2/1 https://neuromancer.sk/std/mnt/mnt2/1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt2_2 ¶
Mnt2_2 returns a Curve which implements mnt/mnt2/2 https://neuromancer.sk/std/mnt/mnt2/2
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt3_1 ¶
Mnt3_1 returns a Curve which implements mnt/mnt3/1 https://neuromancer.sk/std/mnt/mnt3/1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt3_2 ¶
Mnt3_2 returns a Curve which implements mnt/mnt3/2 https://neuromancer.sk/std/mnt/mnt3/2
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt3_3 ¶
Mnt3_3 returns a Curve which implements mnt/mnt3/3 https://neuromancer.sk/std/mnt/mnt3/3
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt4 ¶
Mnt4 returns a Curve which implements mnt/mnt4 https://neuromancer.sk/std/mnt/mnt4
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt5_1 ¶
Mnt5_1 returns a Curve which implements mnt/mnt5/1 https://neuromancer.sk/std/mnt/mnt5/1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt5_2 ¶
Mnt5_2 returns a Curve which implements mnt/mnt5/2 https://neuromancer.sk/std/mnt/mnt5/2
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Mnt5_3 ¶
Mnt5_3 returns a Curve which implements mnt/mnt5/3 https://neuromancer.sk/std/mnt/mnt5/3
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.