Documentation
¶
Overview ¶
package nums is a collection of named elliptic curves.
Microsoft Nothing Up My Sleeve (NUMS) curves from: <https://eprint.iacr.org/2014/130> and <https://tools.ietf.org/html/draft-black-numscurves-02>
Index ¶
- func Ed254Mont() elliptic.Curve
- func Ed255Mers() elliptic.Curve
- func Ed256Mont() elliptic.Curve
- func Ed382Mont() elliptic.Curve
- func Ed383Mers() elliptic.Curve
- func Ed384Mont() elliptic.Curve
- func Ed510Mont() elliptic.Curve
- func Ed511Mers() elliptic.Curve
- func Ed512Mont() elliptic.Curve
- func Numsp256d1() elliptic.Curve
- func Numsp256t1() elliptic.Curve
- func Numsp384d1() elliptic.Curve
- func Numsp384t1() elliptic.Curve
- func Numsp512d1() elliptic.Curve
- func Numsp512t1() elliptic.Curve
- func W254Mont() elliptic.Curve
- func W255Mers() elliptic.Curve
- func W256Mont() elliptic.Curve
- func W382Mont() elliptic.Curve
- func W383Mers() elliptic.Curve
- func W384Mont() elliptic.Curve
- func W510Mont() elliptic.Curve
- func W511Mers() elliptic.Curve
- func W512Mont() elliptic.Curve
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Ed254Mont ¶
Ed254Mont returns a Curve which implements nums/ed-254-mont https://neuromancer.sk/std/nums/ed-254-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed255Mers ¶
Ed255Mers returns a Curve which implements nums/ed-255-mers https://neuromancer.sk/std/nums/ed-255-mers
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed256Mont ¶
Ed256Mont returns a Curve which implements nums/ed-256-mont https://neuromancer.sk/std/nums/ed-256-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed382Mont ¶
Ed382Mont returns a Curve which implements nums/ed-382-mont https://neuromancer.sk/std/nums/ed-382-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed383Mers ¶
Ed383Mers returns a Curve which implements nums/ed-383-mers https://neuromancer.sk/std/nums/ed-383-mers
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed384Mont ¶
Ed384Mont returns a Curve which implements nums/ed-384-mont https://neuromancer.sk/std/nums/ed-384-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed510Mont ¶
Ed510Mont returns a Curve which implements nums/ed-510-mont https://neuromancer.sk/std/nums/ed-510-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed511Mers ¶
Ed511Mers returns a Curve which implements nums/ed-511-mers https://neuromancer.sk/std/nums/ed-511-mers
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed512Mont ¶
Ed512Mont returns a Curve which implements nums/ed-512-mont https://neuromancer.sk/std/nums/ed-512-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Numsp256d1 ¶
Numsp256d1 returns a Curve which implements nums/numsp256d1 https://neuromancer.sk/std/nums/numsp256d1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Numsp256t1 ¶
Numsp256t1 returns a Curve which implements nums/numsp256t1 https://neuromancer.sk/std/nums/numsp256t1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Numsp384d1 ¶
Numsp384d1 returns a Curve which implements nums/numsp384d1 https://neuromancer.sk/std/nums/numsp384d1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Numsp384t1 ¶
Numsp384t1 returns a Curve which implements nums/numsp384t1 https://neuromancer.sk/std/nums/numsp384t1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Numsp512d1 ¶
Numsp512d1 returns a Curve which implements nums/numsp512d1 https://neuromancer.sk/std/nums/numsp512d1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Numsp512t1 ¶
Numsp512t1 returns a Curve which implements nums/numsp512t1 https://neuromancer.sk/std/nums/numsp512t1
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W254Mont ¶
W254Mont returns a Curve which implements nums/w-254-mont https://neuromancer.sk/std/nums/w-254-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W255Mers ¶
W255Mers returns a Curve which implements nums/w-255-mers https://neuromancer.sk/std/nums/w-255-mers
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W256Mont ¶
W256Mont returns a Curve which implements nums/w-256-mont https://neuromancer.sk/std/nums/w-256-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W382Mont ¶
W382Mont returns a Curve which implements nums/w-382-mont https://neuromancer.sk/std/nums/w-382-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W383Mers ¶
W383Mers returns a Curve which implements nums/w-383-mers https://neuromancer.sk/std/nums/w-383-mers
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W384Mont ¶
W384Mont returns a Curve which implements nums/w-384-mont https://neuromancer.sk/std/nums/w-384-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W510Mont ¶
W510Mont returns a Curve which implements nums/w-510-mont https://neuromancer.sk/std/nums/w-510-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W511Mers ¶
W511Mers returns a Curve which implements nums/w-511-mers https://neuromancer.sk/std/nums/w-511-mers
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func W512Mont ¶
W512Mont returns a Curve which implements nums/w-512-mont https://neuromancer.sk/std/nums/w-512-mont
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.