Documentation
¶
Overview ¶
package oakley is a collection of named elliptic curves.
Oakley groups from <https://tools.ietf.org/html/rfc2409> and <https://tools.ietf.org/html/rfc5114>
Index ¶
- func Oakley192BitRandomECPGroup() elliptic.Curve
- func Oakley224BitRandomECPGroup() elliptic.Curve
- func Oakley256BitRandomECPGroup() elliptic.Curve
- func Oakley384BitRandomECPGroup() elliptic.Curve
- func Oakley521BitRandomECPGroup() elliptic.Curve
- func OakleyGroup3() elliptic.Curve
- func OakleyGroup4() elliptic.Curve
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Oakley192BitRandomECPGroup ¶
Oakley192BitRandomECPGroup returns a Curve which implements oakley/192-bit Random ECP Group https://neuromancer.sk/std/oakley/192-bit%20Random%20ECP%20Group
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Oakley224BitRandomECPGroup ¶
Oakley224BitRandomECPGroup returns a Curve which implements oakley/224-bit Random ECP Group https://neuromancer.sk/std/oakley/224-bit%20Random%20ECP%20Group
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Oakley256BitRandomECPGroup ¶
Oakley256BitRandomECPGroup returns a Curve which implements oakley/256-bit Random ECP Group https://neuromancer.sk/std/oakley/256-bit%20Random%20ECP%20Group
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Oakley384BitRandomECPGroup ¶
Oakley384BitRandomECPGroup returns a Curve which implements oakley/384-bit Random ECP Group https://neuromancer.sk/std/oakley/384-bit%20Random%20ECP%20Group
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Oakley521BitRandomECPGroup ¶
Oakley521BitRandomECPGroup returns a Curve which implements oakley/521-bit Random ECP Group https://neuromancer.sk/std/oakley/521-bit%20Random%20ECP%20Group
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func OakleyGroup3 ¶
OakleyGroup3 returns a Curve which implements oakley/Oakley Group 3 https://neuromancer.sk/std/oakley/Oakley%20Group%203
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func OakleyGroup4 ¶
OakleyGroup4 returns a Curve which implements oakley/Oakley Group 4 https://neuromancer.sk/std/oakley/Oakley%20Group%204
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.