Documentation
¶
Overview ¶
package oscaa is a collection of named elliptic curves.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SM2 ¶
SM2 returns a Curve which implements oscaa/SM2 https://neuromancer.sk/std/oscaa/SM2
OID: 1.2.156.10197.1.301
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.