Documentation
¶
Overview ¶
package other is a collection of named elliptic curves.
An assortment of some other curves.
Index ¶
- func BADA55R256() elliptic.Curve
- func BADA55VPR2_224() elliptic.Curve
- func BADA55VPR224() elliptic.Curve
- func BADA55VR224() elliptic.Curve
- func BADA55VR256() elliptic.Curve
- func BADA55VR384() elliptic.Curve
- func Curve448() elliptic.Curve
- func Curve1174() elliptic.Curve
- func Curve4417() elliptic.Curve
- func Curve22103() elliptic.Curve
- func Curve25519() elliptic.Curve
- func Curve41417() elliptic.Curve
- func Curve67254() elliptic.Curve
- func Curve383187() elliptic.Curve
- func E222() elliptic.Curve
- func E382() elliptic.Curve
- func E521() elliptic.Curve
- func Ed448() elliptic.Curve
- func Ed448Goldilocks() elliptic.Curve
- func Ed25519() elliptic.Curve
- func Fp224BN() elliptic.Curve
- func Fp254BNa() elliptic.Curve
- func Fp254BNb() elliptic.Curve
- func Fp256BN() elliptic.Curve
- func Fp384BN() elliptic.Curve
- func Fp512BN() elliptic.Curve
- func JubJub() elliptic.Curve
- func M221() elliptic.Curve
- func M383() elliptic.Curve
- func M511() elliptic.Curve
- func MDC201601() elliptic.Curve
- func Pallas() elliptic.Curve
- func Ssc160() elliptic.Curve
- func Ssc192() elliptic.Curve
- func Ssc224() elliptic.Curve
- func Ssc256() elliptic.Curve
- func Ssc288() elliptic.Curve
- func Ssc320() elliptic.Curve
- func Ssc384() elliptic.Curve
- func Ssc512() elliptic.Curve
- func Tom256() elliptic.Curve
- func Tom384() elliptic.Curve
- func Tom521() elliptic.Curve
- func Tweedledee() elliptic.Curve
- func Tweedledum() elliptic.Curve
- func Vesta() elliptic.Curve
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BADA55R256 ¶
BADA55R256 returns a Curve which implements other/BADA55-R-256 https://neuromancer.sk/std/other/BADA55-R-256
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BADA55VPR2_224 ¶
BADA55VPR2_224 returns a Curve which implements other/BADA55-VPR2-224 https://neuromancer.sk/std/other/BADA55-VPR2-224
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BADA55VPR224 ¶
BADA55VPR224 returns a Curve which implements other/BADA55-VPR-224 https://neuromancer.sk/std/other/BADA55-VPR-224
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BADA55VR224 ¶
BADA55VR224 returns a Curve which implements other/BADA55-VR-224 https://neuromancer.sk/std/other/BADA55-VR-224
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BADA55VR256 ¶
BADA55VR256 returns a Curve which implements other/BADA55-VR-256 https://neuromancer.sk/std/other/BADA55-VR-256
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func BADA55VR384 ¶
BADA55VR384 returns a Curve which implements other/BADA55-VR-384 https://neuromancer.sk/std/other/BADA55-VR-384
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve448 ¶
Curve448 returns a Curve which implements other/Curve448 https://neuromancer.sk/std/other/Curve448
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve1174 ¶
Curve1174 returns a Curve which implements other/Curve1174 https://neuromancer.sk/std/other/Curve1174
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve4417 ¶
Curve4417 returns a Curve which implements other/Curve4417 https://neuromancer.sk/std/other/Curve4417
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve22103 ¶
Curve22103 returns a Curve which implements other/Curve22103 https://neuromancer.sk/std/other/Curve22103
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve25519 ¶
Curve25519 returns a Curve which implements other/Curve25519 https://neuromancer.sk/std/other/Curve25519
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve41417 ¶
Curve41417 returns a Curve which implements other/Curve41417 https://neuromancer.sk/std/other/Curve41417
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve67254 ¶
Curve67254 returns a Curve which implements other/Curve67254 https://neuromancer.sk/std/other/Curve67254
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Curve383187 ¶
Curve383187 returns a Curve which implements other/Curve383187 https://neuromancer.sk/std/other/Curve383187
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func E222 ¶
E222 returns a Curve which implements other/E-222 https://neuromancer.sk/std/other/E-222
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func E382 ¶
E382 returns a Curve which implements other/E-382 https://neuromancer.sk/std/other/E-382
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func E521 ¶
E521 returns a Curve which implements other/E-521 https://neuromancer.sk/std/other/E-521
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed448 ¶
Ed448 returns a Curve which implements other/Ed448 https://neuromancer.sk/std/other/Ed448
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed448Goldilocks ¶
Ed448Goldilocks returns a Curve which implements other/Ed448-Goldilocks https://neuromancer.sk/std/other/Ed448-Goldilocks
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ed25519 ¶
Ed25519 returns a Curve which implements other/Ed25519 https://neuromancer.sk/std/other/Ed25519
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Fp224BN ¶
Fp224BN returns a Curve which implements other/Fp224BN https://neuromancer.sk/std/other/Fp224BN
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Fp254BNa ¶
Fp254BNa returns a Curve which implements other/Fp254BNa https://neuromancer.sk/std/other/Fp254BNa
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Fp254BNb ¶
Fp254BNb returns a Curve which implements other/Fp254BNb https://neuromancer.sk/std/other/Fp254BNb Aliases:
- bn/bn254
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Fp256BN ¶
Fp256BN returns a Curve which implements other/Fp256BN https://neuromancer.sk/std/other/Fp256BN
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Fp384BN ¶
Fp384BN returns a Curve which implements other/Fp384BN https://neuromancer.sk/std/other/Fp384BN
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Fp512BN ¶
Fp512BN returns a Curve which implements other/Fp512BN https://neuromancer.sk/std/other/Fp512BN
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func JubJub ¶
JubJub returns a Curve which implements other/JubJub https://neuromancer.sk/std/other/JubJub
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func M221 ¶
M221 returns a Curve which implements other/M-221 https://neuromancer.sk/std/other/M-221
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func M383 ¶
M383 returns a Curve which implements other/M-383 https://neuromancer.sk/std/other/M-383
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func M511 ¶
M511 returns a Curve which implements other/M-511 https://neuromancer.sk/std/other/M-511
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func MDC201601 ¶
MDC201601 returns a Curve which implements other/MDC201601 https://neuromancer.sk/std/other/MDC201601
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Pallas ¶
Pallas returns a Curve which implements other/Pallas https://neuromancer.sk/std/other/Pallas
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc160 ¶
Ssc160 returns a Curve which implements other/ssc-160 https://neuromancer.sk/std/other/ssc-160
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc192 ¶
Ssc192 returns a Curve which implements other/ssc-192 https://neuromancer.sk/std/other/ssc-192
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc224 ¶
Ssc224 returns a Curve which implements other/ssc-224 https://neuromancer.sk/std/other/ssc-224
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc256 ¶
Ssc256 returns a Curve which implements other/ssc-256 https://neuromancer.sk/std/other/ssc-256
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc288 ¶
Ssc288 returns a Curve which implements other/ssc-288 https://neuromancer.sk/std/other/ssc-288
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc320 ¶
Ssc320 returns a Curve which implements other/ssc-320 https://neuromancer.sk/std/other/ssc-320
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc384 ¶
Ssc384 returns a Curve which implements other/ssc-384 https://neuromancer.sk/std/other/ssc-384
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Ssc512 ¶
Ssc512 returns a Curve which implements other/ssc-512 https://neuromancer.sk/std/other/ssc-512
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Tom256 ¶
Tom256 returns a Curve which implements other/Tom-256 https://neuromancer.sk/std/other/Tom-256
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Tom384 ¶
Tom384 returns a Curve which implements other/Tom-384 https://neuromancer.sk/std/other/Tom-384
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Tom521 ¶
Tom521 returns a Curve which implements other/Tom-521 https://neuromancer.sk/std/other/Tom-521
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Tweedledee ¶
Tweedledee returns a Curve which implements other/Tweedledee https://neuromancer.sk/std/other/Tweedledee
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Tweedledum ¶
Tweedledum returns a Curve which implements other/Tweedledum https://neuromancer.sk/std/other/Tweedledum
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Vesta ¶
Vesta returns a Curve which implements other/Vesta https://neuromancer.sk/std/other/Vesta
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.