Documentation
¶
Overview ¶
package x962 is a collection of named elliptic curves.
ANSI x9.62 example curves.
Index ¶
- func C2pnb163v1() elliptic.Curve
- func C2pnb163v2() elliptic.Curve
- func C2pnb163v3() elliptic.Curve
- func C2pnb176w1() elliptic.Curve
- func C2pnb208w1() elliptic.Curve
- func C2pnb272w1() elliptic.Curve
- func C2pnb304w1() elliptic.Curve
- func C2pnb368w1() elliptic.Curve
- func C2tnb191v1() elliptic.Curve
- func C2tnb191v2() elliptic.Curve
- func C2tnb191v3() elliptic.Curve
- func C2tnb239v1() elliptic.Curve
- func C2tnb239v2() elliptic.Curve
- func C2tnb239v3() elliptic.Curve
- func C2tnb359v1() elliptic.Curve
- func C2tnb431r1() elliptic.Curve
- func Prime192v1() elliptic.Curve
- func Prime192v2() elliptic.Curve
- func Prime192v3() elliptic.Curve
- func Prime239v1() elliptic.Curve
- func Prime239v2() elliptic.Curve
- func Prime239v3() elliptic.Curve
- func Prime256v1() elliptic.Curve
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func C2pnb163v1 ¶
C2pnb163v1 returns a Curve which implements x962/c2pnb163v1 https://neuromancer.sk/std/x962/c2pnb163v1
OID: 1.2.840.10045.3.0.1 Aliases:
- wtls/wap-wsg-idm-ecid-wtls5
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb163v2 ¶
C2pnb163v2 returns a Curve which implements x962/c2pnb163v2 https://neuromancer.sk/std/x962/c2pnb163v2
OID: 1.2.840.10045.3.0.2
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb163v3 ¶
C2pnb163v3 returns a Curve which implements x962/c2pnb163v3 https://neuromancer.sk/std/x962/c2pnb163v3
OID: 1.2.840.10045.3.0.3
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb176w1 ¶
C2pnb176w1 returns a Curve which implements x962/c2pnb176w1 https://neuromancer.sk/std/x962/c2pnb176w1
OID: 1.2.840.10045.3.0.4
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb208w1 ¶
C2pnb208w1 returns a Curve which implements x962/c2pnb208w1 https://neuromancer.sk/std/x962/c2pnb208w1
OID: 1.2.840.10045.3.0.10
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb272w1 ¶
C2pnb272w1 returns a Curve which implements x962/c2pnb272w1 https://neuromancer.sk/std/x962/c2pnb272w1
OID: 1.2.840.10045.3.0.16
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb304w1 ¶
C2pnb304w1 returns a Curve which implements x962/c2pnb304w1 https://neuromancer.sk/std/x962/c2pnb304w1
OID: 1.2.840.10045.3.0.17
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2pnb368w1 ¶
C2pnb368w1 returns a Curve which implements x962/c2pnb368w1 https://neuromancer.sk/std/x962/c2pnb368w1
OID: 1.2.840.10045.3.0.19
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb191v1 ¶
C2tnb191v1 returns a Curve which implements x962/c2tnb191v1 https://neuromancer.sk/std/x962/c2tnb191v1
OID: 1.2.840.10045.3.0.5
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb191v2 ¶
C2tnb191v2 returns a Curve which implements x962/c2tnb191v2 https://neuromancer.sk/std/x962/c2tnb191v2
OID: 1.2.840.10045.3.0.6
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb191v3 ¶
C2tnb191v3 returns a Curve which implements x962/c2tnb191v3 https://neuromancer.sk/std/x962/c2tnb191v3
OID: 1.2.840.10045.3.0.7
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb239v1 ¶
C2tnb239v1 returns a Curve which implements x962/c2tnb239v1 https://neuromancer.sk/std/x962/c2tnb239v1
OID: 1.2.840.10045.3.0.11
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb239v2 ¶
C2tnb239v2 returns a Curve which implements x962/c2tnb239v2 https://neuromancer.sk/std/x962/c2tnb239v2
OID: 1.2.840.10045.3.0.12
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb239v3 ¶
C2tnb239v3 returns a Curve which implements x962/c2tnb239v3 https://neuromancer.sk/std/x962/c2tnb239v3
OID: 1.2.840.10045.3.0.13
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb359v1 ¶
C2tnb359v1 returns a Curve which implements x962/c2tnb359v1 https://neuromancer.sk/std/x962/c2tnb359v1
OID: 1.2.840.10045.3.0.18
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func C2tnb431r1 ¶
C2tnb431r1 returns a Curve which implements x962/c2tnb431r1 https://neuromancer.sk/std/x962/c2tnb431r1
OID: 1.2.840.10045.3.0.20
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime192v1 ¶ added in v1.1.0
Prime192v1 returns a Curve which implements x962/prime192v1 https://neuromancer.sk/std/x962/prime192v1
OID: 1.2.840.10045.3.1.1 Aliases:
- secg/secp192r1
- nist/P-192
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime192v2 ¶ added in v1.1.0
Prime192v2 returns a Curve which implements x962/prime192v2 https://neuromancer.sk/std/x962/prime192v2
OID: 1.2.840.10045.3.1.2
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime192v3 ¶ added in v1.1.0
Prime192v3 returns a Curve which implements x962/prime192v3 https://neuromancer.sk/std/x962/prime192v3
OID: 1.2.840.10045.3.1.3
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime239v1 ¶ added in v1.1.0
Prime239v1 returns a Curve which implements x962/prime239v1 https://neuromancer.sk/std/x962/prime239v1
OID: 1.2.840.10045.3.1.4
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime239v2 ¶ added in v1.1.0
Prime239v2 returns a Curve which implements x962/prime239v2 https://neuromancer.sk/std/x962/prime239v2
OID: 1.2.840.10045.3.1.5
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime239v3 ¶ added in v1.1.0
Prime239v3 returns a Curve which implements x962/prime239v3 https://neuromancer.sk/std/x962/prime239v3
OID: 1.2.840.10045.3.1.6
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func Prime256v1 ¶ added in v1.1.0
Prime256v1 returns a Curve which implements x962/prime256v1 https://neuromancer.sk/std/x962/prime256v1
OID: 1.2.840.10045.3.1.7 Aliases:
- secg/secp256r1
- nist/P-256
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
Types ¶
This section is empty.